@@ -12,10 +12,11 @@
 #include "background-manager.h"
 #include "background.h"
 #include "background-cache.h"
+#include "layersurface-priv.h"
 #include "manager.h"
 #include "monitor/monitor.h"
 #include "phosh-wayland.h"
-#include "shell.h"
+#include "shell-priv.h"
 #include "util.h"
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
