@@ -13,12 +13,12 @@
 #include "call-notification.h"
 #include "calls-manager.h"
 #include "keypad.h"
-#include "lockscreen.h"
+#include "layersurface-priv.h"
+#include "lockscreen-priv.h"
 #include "notifications/notify-manager.h"
 #include "notifications/notification-frame.h"
-#include "osk-button.h"
 #include "osk-manager.h"
-#include "shell.h"
+#include "shell-priv.h"
 #include "util.h"
 #include "widget-box.h"
 #include "wall-clock.h"
@@ -45,7 +45,7 @@
  * and unlock keypad. It handles displaying ongoing calls when the
  * shell is locked and can be extended via plugins.
  *
- * Other outputs are locked via [type@Phosh.Lockshield]s.
+ * Other outputs are locked via PhoshLockshields.
  *
  * # CSS nodes
  *
@@ -1030,7 +1030,6 @@ phosh_lockscreen_class_init (PhoshLockscreenClass *klass)
                                          NULL, G_TYPE_NONE, 0);
 
   g_type_ensure (PHOSH_TYPE_KEYPAD);
-  g_type_ensure (PHOSH_TYPE_OSK_BUTTON);
   g_type_ensure (PHOSH_TYPE_WIDGET_BOX);
   gtk_widget_class_set_css_name (widget_class, "phosh-lockscreen");
   gtk_widget_class_set_template_from_resource (widget_class,
@@ -1097,7 +1096,7 @@ phosh_lockscreen_init (PhoshLockscreen *self)
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
-  /* LTR does't work for the deck
+  /* LTR doesn't work for the deck
    * https://gitlab.gnome.org/World/Phosh/phosh/-/issues/1132 */
   gtk_widget_set_direction (GTK_WIDGET (priv->deck), GTK_TEXT_DIR_LTR);
 }
