@@ -30,6 +30,12 @@ enum {
 };
 static GParamSpec *props[PROP_LAST_PROP];
 
+enum {
+  DONE,
+  N_SIGNALS
+};
+static guint signals[N_SIGNALS];
+
 typedef struct {
   GtkBox       *toplevel_box;
 
@@ -160,9 +166,9 @@ phosh_status_page_remove (GtkContainer *container,
 
 static void
 phosh_status_page_forall (GtkContainer *container,
-                                      gboolean      include_internals,
-                                      GtkCallback   callback,
-                                      gpointer      callback_data)
+                          gboolean      include_internals,
+                          GtkCallback   callback,
+                          gpointer      callback_data)
 {
   PhoshStatusPage *self = PHOSH_STATUS_PAGE (container);
   PhoshStatusPagePrivate *priv = phosh_status_page_get_instance_private (self);
@@ -224,6 +230,18 @@ phosh_status_page_class_init (PhoshStatusPageClass *klass)
 
   g_object_class_install_properties (object_class, PROP_LAST_PROP, props);
 
+  /**
+   * PhoshStatusPage::done
+   *
+   * The status page should be closed
+   */
+  signals[DONE] = g_signal_new ("done",
+                                G_TYPE_FROM_CLASS (klass),
+                                G_SIGNAL_RUN_LAST,
+                                0, NULL, NULL, NULL,
+                                G_TYPE_NONE,
+                                0);
+
   g_type_ensure (PHOSH_TYPE_STATUS_PAGE_PLACEHOLDER);
   gtk_widget_class_set_template_from_resource (widget_class, "/mobi/phosh/ui/status-page.ui");
 
