@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2018 Purism SPC
+ *               2024-2025 The Phosh Developers
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -32,6 +33,7 @@
 #include <fcntl.h>
 #endif
 
+#include <math.h>
 
 static gboolean have_gnome_software = -1;
 
@@ -770,3 +772,141 @@ phosh_util_open_settings_panel (const char *panel)
                             (GAsyncReadyCallback) on_dbus_proxy_new_ready,
                             g_strdup (panel));
 }
+
+#define MINIMUM_SCALE_FACTOR 1.0f
+#define MAXIMUM_SCALE_FACTOR 4.0f
+#define SCALE_FACTORS_PER_INTEGER 4
+#define SCALE_FACTORS_STEPS (1.0 / (float) SCALE_FACTORS_PER_INTEGER)
+#define MINIMUM_LOGICAL_AREA_LANDSCAPE (800 * 480)
+#define MINIMUM_LOGICAL_AREA_PORTRAIT (360 * 720)
+
+static gboolean
+is_logical_size_large_enough (float width, float height)
+{
+  int area = (width > height) ? MINIMUM_LOGICAL_AREA_LANDSCAPE : MINIMUM_LOGICAL_AREA_PORTRAIT;
+
+  return width * height >= area;
+}
+
+
+static gboolean
+is_valid_scale (float width, float height, float scale)
+{
+  float scaled_h = height / scale;
+  float scaled_w = width / scale;
+
+  if (scale < MINIMUM_SCALE_FACTOR || scale > MAXIMUM_SCALE_FACTOR)
+    return FALSE;
+
+  return is_logical_size_large_enough (floorf (scaled_w), floorf(scaled_h));
+}
+
+static float
+get_closest_scale_factor_for_resolution (float width, float height, float scale, float threshold)
+{
+  unsigned int i;
+  float scaled_h;
+  float scaled_w;
+  float best_scale;
+  float base_scaled_w;
+  gboolean found_one;
+
+  best_scale = 0;
+
+  if (!is_valid_scale (width, height, scale))
+    return 0.0;
+
+  if (G_APPROX_VALUE (fmodf (width, scale), 0.0, FLT_EPSILON) &&
+      G_APPROX_VALUE (fmodf (height, scale), 0.0, FLT_EPSILON))
+    return scale;
+
+  i = 0;
+  found_one = FALSE;
+  base_scaled_w = floorf (width / scale);
+
+  do {
+    for (int j = 0; j < 2; j++) {
+      float current_scale;
+      int offset = i * (j ? 1 : -1);
+
+      scaled_w = base_scaled_w + offset;
+      current_scale = width / scaled_w;
+      scaled_h = height / current_scale;
+
+      if (current_scale >= scale + threshold ||
+          current_scale <= scale - threshold ||
+          current_scale < MINIMUM_SCALE_FACTOR ||
+          current_scale > MAXIMUM_SCALE_FACTOR) {
+        return best_scale;
+      }
+
+      if (G_APPROX_VALUE (floorf (scaled_h), scaled_h, FLT_EPSILON)) {
+        found_one = TRUE;
+
+        if (fabsf (current_scale - scale) < fabsf (best_scale - scale))
+          best_scale = current_scale;
+      }
+    }
+    i++;
+  } while (!found_one);
+
+  return best_scale;
+}
+
+/**
+ * phosh_util_calculate_supported_mode_scales:
+ * @width: The mode's width
+ * @height: The modes' height
+ * @n_supported_scales:(out): The number of calculated scales
+ * @fractional: Whether to include fractional scales
+ *
+ * Calculate supported scales for a given mode.
+ */
+float *
+phosh_util_calculate_supported_mode_scales (guint32   width,
+                                            guint32   height,
+                                            int      *n_supported_scales,
+                                            gboolean  fractional)
+{
+  GArray *supported_scales;
+
+  supported_scales = g_array_new (FALSE, FALSE, sizeof (float));
+
+  if (fractional) {
+    for (float i = floorf (MINIMUM_SCALE_FACTOR); i <= ceilf (MAXIMUM_SCALE_FACTOR); i++) {
+      float max_bound;
+
+      if (G_APPROX_VALUE (floorf (MINIMUM_SCALE_FACTOR), i, FLT_EPSILON) ||
+          G_APPROX_VALUE (ceilf (MAXIMUM_SCALE_FACTOR), i, FLT_EPSILON)) {
+        max_bound = SCALE_FACTORS_STEPS;
+      } else {
+        max_bound = SCALE_FACTORS_STEPS / 2.0;
+      }
+
+      for (int j = 0; j < SCALE_FACTORS_PER_INTEGER; j++) {
+        float scale;
+        float scale_value = i + j * SCALE_FACTORS_STEPS;
+
+        scale = get_closest_scale_factor_for_resolution (width, height,
+                                                         scale_value,
+                                                         max_bound);
+        if (scale > 0.0)
+          g_array_append_val (supported_scales, scale);
+      }
+    }
+  } else {
+    for (float f = floorf (MINIMUM_SCALE_FACTOR); f <= ceilf (MAXIMUM_SCALE_FACTOR); f++) {
+      if (is_valid_scale (width, height, f)) {
+        g_array_append_val (supported_scales, f);
+      }
+    }
+  }
+
+  if (supported_scales->len == 0) {
+    float fallback_scale = 1.0;
+    g_array_append_val (supported_scales, fallback_scale);
+  }
+
+  *n_supported_scales = supported_scales->len;
+  return (float *) g_array_free (supported_scales, FALSE);
+}
