@@ -18,7 +18,7 @@ css_setup (void)
   GError *error = NULL;
 
   provider = gtk_css_provider_new ();
-  file = g_file_new_for_uri ("resource:///sm/puri/phosh/stylesheet/adwaita-dark.css");
+  file = g_file_new_for_uri ("resource:///mobi/phosh/stylesheet/adwaita-dark.css");
 
   if (!gtk_css_provider_load_from_file (provider, file, &error)) {
     g_warning ("Failed to load CSS file: %s", error->message);
